==> pgbackrest_1.23.orig.tar.gz: pgbackrest-release-1.23/src/config/config.auto.md <==
# Query Configuration Settings

## cfgOptionIndexTotal

Total index values allowed.

### Truth Table:

This function is valid when `cfgRuleOptionValid()` = `true`. Permutations that return `1` are excluded for brevity.

| Function | uiOptionId | Result |
| -------- | ---------- | ------ |
| cfgOptionIndexTotal | `CFGOPT_DB1_CMD` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB1_CONFIG` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB1_HOST` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB1_PATH` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB1_PORT` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB1_SOCKET_PATH` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB1_SSH_PORT` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB1_USER` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB2_CMD` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB2_CONFIG` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB2_HOST` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB2_PATH` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB2_PORT` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB2_SOCKET_PATH` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB2_SSH_PORT` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB2_USER` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB3_CMD` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB3_CONFIG` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB3_HOST` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB3_PATH` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB3_PORT` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB3_SOCKET_PATH` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB3_SSH_PORT` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB3_USER` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB4_CMD` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB4_CONFIG` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB4_HOST` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB4_PATH` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB4_PORT` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB4_SOCKET_PATH` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB4_SSH_PORT` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB4_USER` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB5_CMD` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB5_CONFIG` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB5_HOST` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB5_PATH` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB5_PORT` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB5_SOCKET_PATH` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB5_SSH_PORT` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB5_USER` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB6_CMD` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB6_CONFIG` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB6_HOST` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB6_PATH` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB6_PORT` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB6_SOCKET_PATH` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB6_SSH_PORT` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB6_USER` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB7_CMD` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB7_CONFIG` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB7_HOST` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB7_PATH` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB7_PORT` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB7_SOCKET_PATH` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB7_SSH_PORT` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB7_USER` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB8_CMD` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB8_CONFIG` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB8_HOST` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB8_PATH` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB8_PORT` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB8_SOCKET_PATH` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB8_SSH_PORT` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB8_USER` | `8` |

==> pgbackrest_1.25.orig.tar.gz: pgbackrest-release-1.25/src/config/config.auto.md <==
# Command and Option Configuration

## cfgOptionIndexTotal

Total index values allowed.

### Truth Table:

This function is valid when `cfgRuleOptionValid()` = `true`. Permutations that return `1` are excluded for brevity.

| Function | optionId | Result |
| -------- | -------- | ------ |
| cfgOptionIndexTotal | `CFGOPT_DB1_CMD` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB1_CONFIG` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB1_HOST` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB1_PATH` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB1_PORT` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB1_SOCKET_PATH` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB1_SSH_PORT` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB1_USER` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB2_CMD` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB2_CONFIG` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB2_HOST` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB2_PATH` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB2_PORT` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB2_SOCKET_PATH` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB2_SSH_PORT` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB2_USER` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB3_CMD` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB3_CONFIG` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB3_HOST` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB3_PATH` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB3_PORT` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB3_SOCKET_PATH` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB3_SSH_PORT` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB3_USER` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB4_CMD` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB4_CONFIG` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB4_HOST` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB4_PATH` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB4_PORT` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB4_SOCKET_PATH` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB4_SSH_PORT` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB4_USER` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB5_CMD` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB5_CONFIG` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB5_HOST` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB5_PATH` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB5_PORT` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB5_SOCKET_PATH` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB5_SSH_PORT` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB5_USER` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB6_CMD` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB6_CONFIG` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB6_HOST` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB6_PATH` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB6_PORT` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB6_SOCKET_PATH` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB6_SSH_PORT` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB6_USER` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB7_CMD` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB7_CONFIG` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB7_HOST` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB7_PATH` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB7_PORT` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB7_SOCKET_PATH` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB7_SSH_PORT` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB7_USER` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB8_CMD` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB8_CONFIG` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB8_HOST` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB8_PATH` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB8_PORT` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB8_SOCKET_PATH` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB8_SSH_PORT` | `8` |
| cfgOptionIndexTotal | `CFGOPT_DB8_USER` | `8` |
